import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_gallery_picker/src/providers/ImagesProvider.dart';
import 'package:flutter_gallery_picker/src/widgets/ImageThumbWidget.dart';
import 'package:flutter_gallery_picker/src/widgets/IsLoadingWidget.dart';
import 'package:photo_gallery/photo_gallery.dart';
import 'package:provider/provider.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

class AlbumImagesScreen extends StatelessWidget {
  final Album album;

  const AlbumImagesScreen({Key key, this.album}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (_) => ImagesProvider(),
      child: Scaffold(
        appBar: AppBar(
          title: Text(album.name),
          actions: [
            IconButton(
                icon: Icon(Icons.close),
                onPressed: () {
                  Navigator.of(context).pop(null);
                  Navigator.of(context).pop(null);
                }),
          ],
        ),
        body: Consumer<ImagesProvider>(
          builder: (context, value, child) {
            if (value.mediaList == null) {
              value.getMediaList(album);
              return IsLoadingWidget();
            }

            return SmartRefresher(
              enablePullDown: true,
              enablePullUp: true,
              footer: CustomFooter(
                builder: (BuildContext context, LoadStatus mode) {
                  Widget body;
                  if (mode == LoadStatus.idle) {
                    body = Text("pull up load");
                  } else if (mode == LoadStatus.loading) {
                    body = CupertinoActivityIndicator();
                  } else if (mode == LoadStatus.failed) {
                    body = Text("Load Failed!Click retry!");
                  } else if (mode == LoadStatus.canLoading) {
                    body = Text("release to load more");
                  } else {
                    body = Text("No more Data");
                  }

                  return Container(
                    height: 55.0,
                    child: Center(child: body),
                  );
                },
              ),
              controller: value.refreshController,
              onLoading: value.onLoading,
              child: GridView.builder(
                itemBuilder: (context, index) {
                  return InkWell(
                    child: Stack(
                      children: [
                        Positioned.fill(
                          child: Container(
                            padding: EdgeInsets.all(2),
                            //margin: EdgeInsets.all(5),
                            color: Colors.grey.withOpacity(0.7),
                            child: ImageThumbWidget(
                              thumb: value.mediaList.elementAt(index),
                            ),
                          ),
                        ),
                        Positioned(
                          child: IconButton(
                              icon: Icon(Icons.fullscreen_outlined),
                              onPressed: () {
                                previewImage(context, index, value);
                              }),
                        ),
                      ],
                    ),
                    onLongPress: () async {
                      previewImage(context, index, value);
                    },
                    onTap: () async {
                      var file =
                          await value.mediaList.elementAt(index).getFile();
                      Navigator.of(context).pop(file);
                      Navigator.of(context).pop(file);
                    },
                  );
                },
                itemCount: value.mediaList.length,
                gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                  crossAxisCount: 2,
                  childAspectRatio: 1,
                  mainAxisSpacing: 2,
                  crossAxisSpacing: 2,
                ),
              ),
            );
          },
        ),
      ),
    );
  }

  Future<void> previewImage(context, index, ImagesProvider value) async {
    var file = await value.mediaList.elementAt(index).getFile();

    showDialog<void>(
      context: context,
      barrierDismissible: true,
      builder: (BuildContext dialogContext) {
        return Container(
          child: Image.file(file),
        );
      },
    );
  }
}
