import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_gallery_picker/src/providers/AlbumsProvider.dart';
import 'package:flutter_gallery_picker/src/screens/AlbumImagesScreen.dart';
import 'package:flutter_gallery_picker/src/widgets/ImageThumbWidget.dart';
import 'package:flutter_gallery_picker/src/widgets/IsEmptyWidget.dart';
import 'package:flutter_gallery_picker/src/widgets/IsLoadingWidget.dart';
import 'package:page_transition/page_transition.dart';
import 'package:provider/provider.dart';

class GalleryScreen extends StatelessWidget {

  static Future<File> getImage(BuildContext context) async {
    var file = await Navigator.of(context).push(PageTransition(child: GalleryScreen(), type: PageTransitionType.bottomToTop));
    return file;
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (_) => AlbumsProvider(),
      child: Scaffold(
        appBar: AppBar(
          actions: [
            IconButton(
                icon: Icon(Icons.close),
                onPressed: () {
                  Navigator.of(context).pop(null);
                }),
          ],
        ),
        body: Consumer<AlbumsProvider>(builder: (context, value, child) {
          if(value.albums == null){
            value.getAlbums();
            return IsLoadingWidget();
          }

          if(value.albums.isEmpty){
            return IsEmptyWidget();
          }

          return GridView.builder(
            itemBuilder: (context, index) {
              return InkWell(
                child: Container(
                    padding: EdgeInsets.all(2),
                    //margin: EdgeInsets.all(5),
                    color: Colors.grey.withOpacity(0.7),
                    child: Stack(
                      fit: StackFit.expand,
                      children: [
                        Positioned.fill(
                          child: ImageThumbWidget(
                            thumb: value.albums.elementAt(index),
                          ),
                        ),
                        Wrap(
                          children: [
                            Container(
                              color: Colors.grey.withOpacity(0.7),
                              height: 50,
                              child: Center(
                                child: Text(
                                  "(${value.albums.elementAt(index).count}) ${value.albums.elementAt(index).name ?? "--"}",
                                  style: TextStyle(color: Colors.white),
                                  overflow: TextOverflow.ellipsis,
                                  textAlign: TextAlign.center,
                                ),
                              ),
                            ),
                          ],
                        )
                      ],
                    )),
                onTap: () {
                  Navigator.of(context).push(PageTransition(child: AlbumImagesScreen(album: value.albums.elementAt(index)), type: PageTransitionType.leftToRight));
                },
              );
            },
            itemCount: value.albums.length,
            gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
              crossAxisCount: 2,
              childAspectRatio: 1,
              mainAxisSpacing: 2,
              crossAxisSpacing: 2,
            ),
          );
        },),
      ),
    );
  }
}
